@@ -1,4 +1,4 @@
-import { NEW_PROJECT, LOAD_PROJECT, SAVE_PROJECT, OPEN_CATALOG, SELECT_TOOL_EDIT, UNSELECT_ALL, SET_PROPERTIES, SET_ITEMS_ATTRIBUTES, SET_LINES_ATTRIBUTES, SET_HOLES_ATTRIBUTES, REMOVE, UNDO, ROLLBACK, OPEN_PROJECT_CONFIGURATOR, SET_PROJECT_PROPERTIES, INIT_CATALOG, UPDATE_MOUSE_COORDS, UPDATE_ZOOM_SCALE, TOGGLE_SNAP } from '../constants';
+import { NEW_PROJECT, LOAD_PROJECT, SAVE_PROJECT, OPEN_CATALOG, SELECT_TOOL_EDIT, UNSELECT_ALL, SET_PROPERTIES, SET_ITEMS_ATTRIBUTES, SET_LINES_ATTRIBUTES, SET_HOLES_ATTRIBUTES, REMOVE, UNDO, ROLLBACK, OPEN_PROJECT_CONFIGURATOR, SET_PROJECT_PROPERTIES, INIT_CATALOG, UPDATE_MOUSE_COORDS, UPDATE_ZOOM_SCALE, TOGGLE_SNAP, CHANGE_CATALOG_PAGE, GO_BACK_TO_CATALOG_PAGE } from '../constants';
 
 export function loadProject(sceneJSON) {
   return {
@@ -25,6 +25,21 @@ export function openCatalog() {
   };
 }
 
+export function changeCatalogPage(newPage, oldPage) {
+  return {
+    type: CHANGE_CATALOG_PAGE,
+    newPage: newPage,
+    oldPage: oldPage
+  };
+}
+
+export function goBackToCatalogPage(newPage) {
+  return {
+    type: GO_BACK_TO_CATALOG_PAGE,
+    newPage: newPage
+  };
+}
+
 export function selectToolEdit() {
   return {
     type: SELECT_TOOL_EDIT
