@@ -3,18 +3,19 @@ var _extends = Object.assign || function (target) { for (var i = 1; i < argument
 function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }
 
 import React from 'react';
+import * as SharedStyle from '../../shared-style';
 
 var STYLE = {
-  color: "#2e2f33",
+  color: SharedStyle.PRIMARY_COLOR.alt,
   fontWeight: "300"
 };
 
 export default function ContentTitle(_ref) {
   var children = _ref.children,
-      rest = _objectWithoutProperties(_ref, ["children"]);
+      rest = _objectWithoutProperties(_ref, ['children']);
 
   return React.createElement(
-    "h1",
+    'h1',
     _extends({ style: STYLE }, rest),
     children
   );
