@@ -18,6 +18,8 @@ export var INIT_CATALOG = 'INIT_CATALOG';
 export var UPDATE_MOUSE_COORDS = 'UPDATE_MOUSE_COORDS';
 export var UPDATE_ZOOM_SCALE = 'UPDATE_ZOOM_SCALE';
 export var TOGGLE_SNAP = 'TOGGLE_SNAP';
+export var CHANGE_CATALOG_PAGE = 'CHANGE_CATALOG_PAGE';
+export var GO_BACK_TO_CATALOG_PAGE = 'GO_BACK_TO_CATALOG_PAGE';
 
 // ACTIONS viewer2D
 export var SELECT_TOOL_ZOOM_IN = 'SELECT_TOOL_ZOOM_IN';
@@ -95,7 +97,9 @@ export var PROJECT_ACTIONS = {
   INIT_CATALOG: INIT_CATALOG,
   UPDATE_MOUSE_COORDS: UPDATE_MOUSE_COORDS,
   UPDATE_ZOOM_SCALE: UPDATE_ZOOM_SCALE,
-  TOGGLE_SNAP: TOGGLE_SNAP
+  TOGGLE_SNAP: TOGGLE_SNAP,
+  CHANGE_CATALOG_PAGE: CHANGE_CATALOG_PAGE,
+  GO_BACK_TO_CATALOG_PAGE: GO_BACK_TO_CATALOG_PAGE
 };
 
 export var VIEWER2D_ACTIONS = {
