@@ -587,7 +587,7 @@ function ContainsPoint(polygon, pointX, pointY) {
 export function detectAndUpdateAreas(layer, catalog) {
 
   var verticesArray = []; //array with vertices coords
-  var linesArray = []; //array with edges
+  var linesArray = void 0; //array with edges
 
   var vertexID_to_verticesArrayIndex = {};
   var verticesArrayIndex_to_vertexID = {};
@@ -607,50 +607,13 @@ export function detectAndUpdateAreas(layer, catalog) {
 
   var innerCyclesByVerticesArrayIndex = calculateInnerCyles(verticesArray, linesArray);
 
-  //prendo le coordinate di tutti i vertici dei cicli
-  var coordICBVAI = innerCyclesByVerticesArrayIndex.map(function (cycle) {
-    return cycle.map(function (vertexIndex) {
-      return verticesArray[vertexIndex];
-    });
-  });
-
-  //calcolo i cicli
-  var cycleContaining = coordICBVAI.map(function (el, ind1) {
-    var arr = flatten(el);
-    var toRet = [];
-    coordICBVAI.forEach(function (comp, ind2) {
-      if (ind1 !== ind2 && ContainsPoint(arr, comp[0][0], comp[0][1])) {
-        toRet.push(ind2);
-      }
-    });
-    return toRet;
-  });
-
-  //elimino i cicli nidificati
-  var uniqueCycleContaining = [];
-
-  for (var x = 0; x < cycleContaining.length; x++) {
-    var inCycle = cycleContaining[x];
-
-    var _loop = function _loop(y) {
-      var rifCycle = inCycle[y];
-      uniqueCycleContaining[x] = inCycle.filter(function (val) {
-        return !cycleContaining[rifCycle].includes(val);
-      });
-    };
-
-    for (var y = 0; y < inCycle.length; y++) {
-      _loop(y);
-    }
-  }
-
   var innerCyclesByVerticesID = new List(innerCyclesByVerticesArrayIndex).map(function (cycle) {
     return new List(cycle.map(function (vertexIndex) {
       return verticesArrayIndex_to_vertexID[vertexIndex];
     }));
   });
 
-  var areasID = [];
+  var areaIDs = [];
 
   layer = layer.withMutations(function (layer) {
     //remove areas
@@ -668,8 +631,8 @@ export function detectAndUpdateAreas(layer, catalog) {
       });
 
       if (areaInUse) {
-        areasID[ind] = areaInUse.id;
-        layer = layer.setIn(['areas', areasID[ind], 'holes'], new List());
+        areaIDs[ind] = areaInUse.id;
+        layer.setIn(['areas', areaIDs[ind], 'holes'], new List());
       } else {
         var areaVerticesCoords = cycle.map(function (vertexId) {
           return layer.vertices.get(vertexId);
@@ -678,15 +641,56 @@ export function detectAndUpdateAreas(layer, catalog) {
         var _addArea = addArea(layer, 'area', areaVerticesCoords, catalog),
             area = _addArea.area;
 
-        areasID[ind] = area.id;
+        areaIDs[ind] = area.id;
       }
     });
 
-    for (var _x2 = 0; _x2 < uniqueCycleContaining.length; _x2++) {
-      layer = layer.setIn(['areas', areasID[_x2], 'holes'], new List(uniqueCycleContaining[_x2] ? uniqueCycleContaining[_x2].map(function (el) {
-        return areasID[el];
-      }) : []));
+    // Build a relationship between areas and their coordinates
+    var verticesCoordsForArea = areaIDs.map(function (areaID) {
+      return {
+        id: areaID,
+        vertices: layer.areas.get(areaID).vertices.map(function (vertexID) {
+          return new List([layer.vertices.get(vertexID).x, layer.vertices.get(vertexID).y]);
+        })
+      };
+    });
+
+    // Find all holes for an area
+    var i = void 0,
+        j = void 0;
+    for (i = 0; i < verticesCoordsForArea.length; i++) {
+      var holesList = new List(); // The holes for this area
+      var areaVerticesList = verticesCoordsForArea[i].vertices.flatten().toArray();
+      for (j = 0; j < verticesCoordsForArea.length; j++) {
+        if (i !== j) {
+          var isHole = ContainsPoint(areaVerticesList, verticesCoordsForArea[j].vertices.get(0).get(0), verticesCoordsForArea[j].vertices.get(0).get(1));
+          if (isHole) {
+            holesList = holesList.push(verticesCoordsForArea[j].id);
+          }
+        }
+      }
+      layer.setIn(['areas', verticesCoordsForArea[i].id, 'holes'], holesList);
     }
+
+    // Remove holes which are already holes for other areas
+    areaIDs.forEach(function (areaID) {
+      var doubleHoles = new Set();
+      var areaHoles = layer.getIn(['areas', areaID, 'holes']);
+      areaHoles.forEach(function (areaHoleID) {
+        var holesOfholes = layer.getIn(['areas', areaHoleID, 'holes']);
+        holesOfholes.forEach(function (holeID) {
+          var holeIndex = areaHoles.indexOf(holeID);
+          if (holeIndex !== -1) {
+            doubleHoles.add(holeID);
+          }
+        });
+      });
+      doubleHoles.forEach(function (doubleHoleID) {
+        var holeIndex = areaHoles.indexOf(doubleHoleID);
+        areaHoles = areaHoles.remove(holeIndex);
+      });
+      layer.setIn(['areas', areaID, 'holes'], areaHoles);
+    });
   });
 
   return { layer: layer };
